==> codemirror-minified-5.62.0.tgz: package/mode/rst/rst.js <==
'use strict';(function(k){"object"==typeof exports&&"object"==typeof module?k(require("../../lib/codemirror"),require("../python/python"),require("../stex/stex"),require("../../addon/mode/overlay")):"function"==typeof define&&define.amd?define(["../../lib/codemirror","../python/python","../stex/stex","../../addon/mode/overlay"],k):k(CodeMirror)})(function(k){k.defineMode("rst",function(h,g){var e=/^\*\*[^\*\s](?:[^\*]*[^\*\s])?\*\*/,l=/^\*[^\*\s](?:[^\*]*[^\*\s])?\*/,x=/^``[^`\s](?:[^`]*[^`\s])``/,
y=/^(?:[\d]+(?:[\.,]\d+)*)/,v=/^(?:\s\+[\d]+(?:[\.,]\d+)*)/,r=/^(?:\s\-[\d]+(?:[\.,]\d+)*)/,f=/^[Hh][Tt][Tt][Pp][Ss]?:\/\/(?:[\d\w.-]+)\.(?:\w{2,6})(?:\/[\d\w\#\%\&\-\.\,\/\:\=\?\~]+)*/;h=k.getMode(h,g.backdrop||"rst-base");return k.overlayMode(h,{token:function(c){if(c.match(e)&&c.match(/\W+|$/,!1))return"strong";if(c.match(l)&&c.match(/\W+|$/,!1))return"em";if(c.match(x)&&c.match(/\W+|$/,!1))return"string-2";if(c.match(y))return"number";if(c.match(v))return"positive";if(c.match(r))return"negative";
if(c.match(f))return"link";for(;!(null==c.next()||c.match(e,!1)||c.match(l,!1)||c.match(x,!1)||c.match(y,!1)||c.match(v,!1)||c.match(r,!1)||c.match(f,!1)););return null}},!0)},"python","stex");k.defineMode("rst-base",function(h){function g(b){var a=Array.prototype.slice.call(arguments,1);return b.replace(/{(\d+)}/g,function(d,z){return"undefined"!=typeof a[z]?a[z]:d})}function e(b,a){var d=null;if(b.sol()&&b.match(I,!1))c(a,r,{mode:A,local:k.startState(A)});else if(b.sol()&&b.match(J))c(a,l),d="meta";
else if(b.sol()&&b.match(K))c(a,e),d="header";else if(a.ctx.phase==m||b.match(m,!1))switch(n(a)){case 0:c(a,e,f(m,1));b.match(/^:/);d="meta";break;case 1:c(a,e,f(m,2));b.match(E);d="keyword";b.current().match(/^(?:math|latex)/)&&(a.tmp_stex=!0);break;case 2:c(a,e,f(m,3));b.match(/^:`/);d="meta";break;case 3:a.tmp_stex&&(a.tmp_stex=void 0,a.tmp={mode:B,local:k.startState(B)});if(a.tmp){if("`"==b.peek()){c(a,e,f(m,4));a.tmp=void 0;break}d=a.tmp.mode.token(b,a.tmp.local);break}c(a,e,f(m,4));b.match(F);
d="string";break;case 4:c(a,e,f(m,5));b.match(/^`/);d="meta";break;case 5:c(a,e,f(m,6));b.match(G);break;default:c(a,e)}else if(a.ctx.phase==p||b.match(p,!1))switch(n(a)){case 0:c(a,e,f(p,1));b.match(/^`/);d="meta";break;case 1:c(a,e,f(p,2));b.match(F);d="string";break;case 2:c(a,e,f(p,3));b.match(/^`:/);d="meta";break;case 3:c(a,e,f(p,4));b.match(E);d="keyword";break;case 4:c(a,e,f(p,5));b.match(/^:/);d="meta";break;case 5:c(a,e,f(p,6));b.match(G);break;default:c(a,e)}else if(a.ctx.phase==t||b.match(t,
!1))switch(n(a)){case 0:c(a,e,f(t,1));b.match(/^:/);d="meta";break;case 1:c(a,e,f(t,2));b.match(E);d="keyword";break;case 2:c(a,e,f(t,3));b.match(/^:/);d="meta";break;case 3:c(a,e,f(t,4));b.match(G);break;default:c(a,e)}else if(a.ctx.phase==C||b.match(C,!1))switch(n(a)){case 0:c(a,e,f(C,1));b.match(H);d="variable-2";break;case 1:c(a,e,f(C,2));b.match(/^_?_?/)&&(d="link");break;default:c(a,e)}else if(b.match(L))c(a,e),d="quote";else if(b.match(M))c(a,e),d="quote";else if(b.match(N)){if(c(a,e),!b.peek()||
b.peek().match(/^\W$/))d="link"}else if(a.ctx.phase==q||b.match(q,!1))switch(n(a)){case 0:!b.peek()||b.peek().match(/^\W$/)?c(a,e,f(q,1)):b.match(q);break;case 1:c(a,e,f(q,2));b.match(/^`/);d="link";break;case 2:c(a,e,f(q,3));b.match(F);break;case 3:c(a,e,f(q,4));b.match(/^`_/);d="link";break;default:c(a,e)}else b.match(O)?c(a,y):b.next()&&c(a,e);return d}function l(b,a){var d=null;if(a.ctx.phase==u||b.match(u,!1))switch(n(a)){case 0:c(a,l,f(u,1));b.match(H);d="variable-2";break;case 1:c(a,l,f(u,
2));b.match(P);break;case 2:c(a,l,f(u,3));b.match(Q);d="keyword";break;case 3:c(a,l,f(u,4));b.match(R);d="meta";break;default:c(a,e)}else if(a.ctx.phase==w||b.match(w,!1))switch(n(a)){case 0:c(a,l,f(w,1));b.match(S);d="keyword";b.current().match(/^(?:math|latex)/)?a.tmp_stex=!0:b.current().match(/^python/)&&(a.tmp_py=!0);break;case 1:c(a,l,f(w,2));b.match(T);d="meta";if(b.match(/^latex\s*$/)||a.tmp_stex)a.tmp_stex=void 0,c(a,r,{mode:B,local:k.startState(B)});break;case 2:c(a,l,f(w,3));if(b.match(/^python\s*$/)||
a.tmp_py)a.tmp_py=void 0,c(a,r,{mode:A,local:k.startState(A)});break;default:c(a,e)}else if(a.ctx.phase==D||b.match(D,!1))switch(n(a)){case 0:c(a,l,f(D,1));b.match(U);b.match(V);d="link";break;case 1:c(a,l,f(D,2));b.match(W);d="meta";break;default:c(a,e)}else b.match(X)?(c(a,e),d="quote"):b.match(Y)?(c(a,e),d="quote"):(b.eatSpace(),b.eol()?c(a,e):(b.skipToEnd(),c(a,x),d="comment"));return d}function x(b,a){return v(b,a,"comment")}function y(b,a){return v(b,a,"meta")}function v(b,a,d){if(b.eol()||
b.eatSpace())return b.skipToEnd(),d;c(a,e);return null}function r(b,a){if(a.ctx.mode&&a.ctx.local)return b.sol()?(b.eatSpace()||c(a,e),null):a.ctx.mode.token(b,a.ctx.local);c(a,e);return null}function f(b,a,d,z){return{phase:b,stage:a,mode:d,local:z}}function c(b,a,d){b.tok=a;b.ctx=d||{}}function n(b){return b.ctx.stage||0}var A=k.getMode(h,"python"),B=k.getMode(h,"stex"),G=new RegExp(g("^{0}","(?:\\s*|\\W|$)")),E=new RegExp(g("^{0}","(?:[^\\W\\d_](?:[\\w!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)"));
h=g("(?:{0}|`{1}`)","(?:[^\\W\\d_](?:[\\w!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)","(?:[^\\W\\d_](?:[\\w\\s!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)");var F=new RegExp(g("^{0}","(?:[^\\`]+)")),K=/^([!'#$%&"()*+,-./:;<=>?@\[\\\]^_`{|}~])\1{3,}\s*$/,J=new RegExp(g("^\\.\\.{0}","\\s+")),D=new RegExp(g("^_{0}:{1}|^__:{1}",h,"(?:\\s*|\\W|$)")),w=new RegExp(g("^{0}::{1}",h,"(?:\\s*|\\W|$)")),u=new RegExp(g("^\\|{0}\\|{1}{2}::{3}","(?:[^\\s\\|](?:[^\\|]*[^\\s\\|])?)","\\s+",h,"(?:\\s*|\\W|$)")),X=
new RegExp(g("^\\[(?:\\d+|#{0}?|\\*)]{1}",h,"(?:\\s*|\\W|$)")),Y=new RegExp(g("^\\[{0}\\]{1}",h,"(?:\\s*|\\W|$)")),C=new RegExp(g("^\\|{0}\\|","(?:[^\\s\\|](?:[^\\|]*[^\\s\\|])?)")),L=new RegExp(g("^\\[(?:\\d+|#{0}?|\\*)]_",h)),M=new RegExp(g("^\\[{0}\\]_",h)),N=new RegExp(g("^{0}__?",h)),q=new RegExp(g("^`{0}`_","(?:[^\\`]+)")),m=new RegExp(g("^:{0}:`{1}`{2}","(?:[^\\W\\d_](?:[\\w!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)","(?:[^\\`]+)","(?:\\s*|\\W|$)")),p=new RegExp(g("^`{1}`:{0}:{2}","(?:[^\\W\\d_](?:[\\w!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)",
"(?:[^\\`]+)","(?:\\s*|\\W|$)")),t=new RegExp(g("^:{0}:{1}","(?:[^\\W\\d_](?:[\\w!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)","(?:\\s*|\\W|$)")),S=new RegExp(g("^{0}",h)),T=new RegExp(g("^::{0}","(?:\\s*|\\W|$)")),H=new RegExp(g("^\\|{0}\\|","(?:[^\\s\\|](?:[^\\|]*[^\\s\\|])?)")),P=new RegExp(g("^{0}","\\s+")),Q=new RegExp(g("^{0}",h)),R=new RegExp(g("^::{0}","(?:\\s*|\\W|$)")),U=/^_/,V=new RegExp(g("^{0}|_",h)),W=new RegExp(g("^:{0}","(?:\\s*|\\W|$)")),O=/^::\s*$/,I=/^\s+(?:>>>|In \[\d+\]:)\s/;
return{startState:function(){return{tok:e,ctx:f(void 0,0)}},copyState:function(b){var a=b.ctx,d=b.tmp;a.local&&(a={mode:a.mode,local:k.copyState(a.mode,a.local)});d&&(d={mode:d.mode,local:k.copyState(d.mode,d.local)});return{tok:b.tok,ctx:a,tmp:d}},innerMode:function(b){return b.tmp?{state:b.tmp.local,mode:b.tmp.mode}:b.ctx.mode?{state:b.ctx.local,mode:b.ctx.mode}:null},token:function(b,a){return a.tok(b,a)}}},"python","stex");k.defineMIME("text/x-rst","rst")});

==> codemirror-minified-5.63.0.tgz: package/mode/rst/rst.js <==
'use strict';(function(k){"object"==typeof exports&&"object"==typeof module?k(require("../../lib/codemirror"),require("../python/python"),require("../stex/stex"),require("../../addon/mode/overlay")):"function"==typeof define&&define.amd?define(["../../lib/codemirror","../python/python","../stex/stex","../../addon/mode/overlay"],k):k(CodeMirror)})(function(k){k.defineMode("rst",function(h,g){var e=/^\*\*[^\*\s](?:[^\*]*[^\*\s])?\*\*/,l=/^\*[^\*\s](?:[^\*]*[^\*\s])?\*/,x=/^``[^`\s](?:[^`]*[^`\s])``/,
y=/^(?:[\d]+(?:[\.,]\d+)*)/,v=/^(?:\s\+[\d]+(?:[\.,]\d+)*)/,r=/^(?:\s\-[\d]+(?:[\.,]\d+)*)/,f=RegExp("^[Hh][Tt][Tt][Pp][Ss]?://(?:[\\d\\w.-]+)\\.(?:\\w{2,6})(?:/[\\d\\w\\#\\%\\&\\-\\.\\,\\/\\:\\=\\?\\~]+)*");h=k.getMode(h,g.backdrop||"rst-base");return k.overlayMode(h,{token:function(c){if(c.match(e)&&c.match(/\W+|$/,!1))return"strong";if(c.match(l)&&c.match(/\W+|$/,!1))return"em";if(c.match(x)&&c.match(/\W+|$/,!1))return"string-2";if(c.match(y))return"number";if(c.match(v))return"positive";if(c.match(r))return"negative";
if(c.match(f))return"link";for(;!(null==c.next()||c.match(e,!1)||c.match(l,!1)||c.match(x,!1)||c.match(y,!1)||c.match(v,!1)||c.match(r,!1)||c.match(f,!1)););return null}},!0)},"python","stex");k.defineMode("rst-base",function(h){function g(b){var a=Array.prototype.slice.call(arguments,1);return b.replace(/{(\d+)}/g,function(d,z){return"undefined"!=typeof a[z]?a[z]:d})}function e(b,a){var d=null;if(b.sol()&&b.match(I,!1))c(a,r,{mode:A,local:k.startState(A)});else if(b.sol()&&b.match(J))c(a,l),d="meta";
else if(b.sol()&&b.match(K))c(a,e),d="header";else if(a.ctx.phase==m||b.match(m,!1))switch(n(a)){case 0:c(a,e,f(m,1));b.match(/^:/);d="meta";break;case 1:c(a,e,f(m,2));b.match(E);d="keyword";b.current().match(/^(?:math|latex)/)&&(a.tmp_stex=!0);break;case 2:c(a,e,f(m,3));b.match(/^:`/);d="meta";break;case 3:a.tmp_stex&&(a.tmp_stex=void 0,a.tmp={mode:B,local:k.startState(B)});if(a.tmp){if("`"==b.peek()){c(a,e,f(m,4));a.tmp=void 0;break}d=a.tmp.mode.token(b,a.tmp.local);break}c(a,e,f(m,4));b.match(F);
d="string";break;case 4:c(a,e,f(m,5));b.match(/^`/);d="meta";break;case 5:c(a,e,f(m,6));b.match(G);break;default:c(a,e)}else if(a.ctx.phase==p||b.match(p,!1))switch(n(a)){case 0:c(a,e,f(p,1));b.match(/^`/);d="meta";break;case 1:c(a,e,f(p,2));b.match(F);d="string";break;case 2:c(a,e,f(p,3));b.match(/^`:/);d="meta";break;case 3:c(a,e,f(p,4));b.match(E);d="keyword";break;case 4:c(a,e,f(p,5));b.match(/^:/);d="meta";break;case 5:c(a,e,f(p,6));b.match(G);break;default:c(a,e)}else if(a.ctx.phase==t||b.match(t,
!1))switch(n(a)){case 0:c(a,e,f(t,1));b.match(/^:/);d="meta";break;case 1:c(a,e,f(t,2));b.match(E);d="keyword";break;case 2:c(a,e,f(t,3));b.match(/^:/);d="meta";break;case 3:c(a,e,f(t,4));b.match(G);break;default:c(a,e)}else if(a.ctx.phase==C||b.match(C,!1))switch(n(a)){case 0:c(a,e,f(C,1));b.match(H);d="variable-2";break;case 1:c(a,e,f(C,2));b.match(/^_?_?/)&&(d="link");break;default:c(a,e)}else if(b.match(L))c(a,e),d="quote";else if(b.match(M))c(a,e),d="quote";else if(b.match(N)){if(c(a,e),!b.peek()||
b.peek().match(/^\W$/))d="link"}else if(a.ctx.phase==q||b.match(q,!1))switch(n(a)){case 0:!b.peek()||b.peek().match(/^\W$/)?c(a,e,f(q,1)):b.match(q);break;case 1:c(a,e,f(q,2));b.match(/^`/);d="link";break;case 2:c(a,e,f(q,3));b.match(F);break;case 3:c(a,e,f(q,4));b.match(/^`_/);d="link";break;default:c(a,e)}else b.match(O)?c(a,y):b.next()&&c(a,e);return d}function l(b,a){var d=null;if(a.ctx.phase==u||b.match(u,!1))switch(n(a)){case 0:c(a,l,f(u,1));b.match(H);d="variable-2";break;case 1:c(a,l,f(u,
2));b.match(P);break;case 2:c(a,l,f(u,3));b.match(Q);d="keyword";break;case 3:c(a,l,f(u,4));b.match(R);d="meta";break;default:c(a,e)}else if(a.ctx.phase==w||b.match(w,!1))switch(n(a)){case 0:c(a,l,f(w,1));b.match(S);d="keyword";b.current().match(/^(?:math|latex)/)?a.tmp_stex=!0:b.current().match(/^python/)&&(a.tmp_py=!0);break;case 1:c(a,l,f(w,2));b.match(T);d="meta";if(b.match(/^latex\s*$/)||a.tmp_stex)a.tmp_stex=void 0,c(a,r,{mode:B,local:k.startState(B)});break;case 2:c(a,l,f(w,3));if(b.match(/^python\s*$/)||
a.tmp_py)a.tmp_py=void 0,c(a,r,{mode:A,local:k.startState(A)});break;default:c(a,e)}else if(a.ctx.phase==D||b.match(D,!1))switch(n(a)){case 0:c(a,l,f(D,1));b.match(U);b.match(V);d="link";break;case 1:c(a,l,f(D,2));b.match(W);d="meta";break;default:c(a,e)}else b.match(X)?(c(a,e),d="quote"):b.match(Y)?(c(a,e),d="quote"):(b.eatSpace(),b.eol()?c(a,e):(b.skipToEnd(),c(a,x),d="comment"));return d}function x(b,a){return v(b,a,"comment")}function y(b,a){return v(b,a,"meta")}function v(b,a,d){if(b.eol()||
b.eatSpace())return b.skipToEnd(),d;c(a,e);return null}function r(b,a){if(a.ctx.mode&&a.ctx.local)return b.sol()?(b.eatSpace()||c(a,e),null):a.ctx.mode.token(b,a.ctx.local);c(a,e);return null}function f(b,a,d,z){return{phase:b,stage:a,mode:d,local:z}}function c(b,a,d){b.tok=a;b.ctx=d||{}}function n(b){return b.ctx.stage||0}var A=k.getMode(h,"python"),B=k.getMode(h,"stex"),G=new RegExp(g("^{0}","(?:\\s*|\\W|$)")),E=new RegExp(g("^{0}","(?:[^\\W\\d_](?:[\\w!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)"));
h=g("(?:{0}|`{1}`)","(?:[^\\W\\d_](?:[\\w!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)","(?:[^\\W\\d_](?:[\\w\\s!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)");var F=new RegExp(g("^{0}","(?:[^\\`]+)")),K=RegExp("^([!'#$%&\"()*+,-./:;<=>?@\\[\\\\\\]^_`{|}~])\\1{3,}\\s*$"),J=new RegExp(g("^\\.\\.{0}","\\s+")),D=new RegExp(g("^_{0}:{1}|^__:{1}",h,"(?:\\s*|\\W|$)")),w=new RegExp(g("^{0}::{1}",h,"(?:\\s*|\\W|$)")),u=new RegExp(g("^\\|{0}\\|{1}{2}::{3}","(?:[^\\s\\|](?:[^\\|]*[^\\s\\|])?)","\\s+",h,"(?:\\s*|\\W|$)")),
X=new RegExp(g("^\\[(?:\\d+|#{0}?|\\*)]{1}",h,"(?:\\s*|\\W|$)")),Y=new RegExp(g("^\\[{0}\\]{1}",h,"(?:\\s*|\\W|$)")),C=new RegExp(g("^\\|{0}\\|","(?:[^\\s\\|](?:[^\\|]*[^\\s\\|])?)")),L=new RegExp(g("^\\[(?:\\d+|#{0}?|\\*)]_",h)),M=new RegExp(g("^\\[{0}\\]_",h)),N=new RegExp(g("^{0}__?",h)),q=new RegExp(g("^`{0}`_","(?:[^\\`]+)")),m=new RegExp(g("^:{0}:`{1}`{2}","(?:[^\\W\\d_](?:[\\w!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)","(?:[^\\`]+)","(?:\\s*|\\W|$)")),p=new RegExp(g("^`{1}`:{0}:{2}","(?:[^\\W\\d_](?:[\\w!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)",
"(?:[^\\`]+)","(?:\\s*|\\W|$)")),t=new RegExp(g("^:{0}:{1}","(?:[^\\W\\d_](?:[\\w!\"#$%&'()\\*\\+,\\-\\./:;<=>\\?]*[^\\W_])?)","(?:\\s*|\\W|$)")),S=new RegExp(g("^{0}",h)),T=new RegExp(g("^::{0}","(?:\\s*|\\W|$)")),H=new RegExp(g("^\\|{0}\\|","(?:[^\\s\\|](?:[^\\|]*[^\\s\\|])?)")),P=new RegExp(g("^{0}","\\s+")),Q=new RegExp(g("^{0}",h)),R=new RegExp(g("^::{0}","(?:\\s*|\\W|$)")),U=RegExp("^_"),V=new RegExp(g("^{0}|_",h)),W=new RegExp(g("^:{0}","(?:\\s*|\\W|$)")),O=RegExp("^::\\s*$"),I=RegExp("^\\s+(?:>>>|In \\[\\d+\\]:)\\s");
return{startState:function(){return{tok:e,ctx:f(void 0,0)}},copyState:function(b){var a=b.ctx,d=b.tmp;a.local&&(a={mode:a.mode,local:k.copyState(a.mode,a.local)});d&&(d={mode:d.mode,local:k.copyState(d.mode,d.local)});return{tok:b.tok,ctx:a,tmp:d}},innerMode:function(b){return b.tmp?{state:b.tmp.local,mode:b.tmp.mode}:b.ctx.mode?{state:b.ctx.local,mode:b.ctx.mode}:null},token:function(b,a){return a.tok(b,a)}}},"python","stex");k.defineMIME("text/x-rst","rst")});
